@@ -109,8 +109,8 @@ class YamlDictWrapper(dict):
     def __getattr__(self, item):
         try:
             return YamlListWrapper.wrap(super(YamlDictWrapper, self).__getitem__(item))
-        except KeyError:
-            raise XacroException("No such key: '{}'".format(item))
+        except KeyError:  # raise AttributeError instead to support hasattr()
+            raise AttributeError("The yaml dictionary has no key '{}'".format(item))
 
     __getitem__ = __getattr__
 
@@ -754,10 +754,6 @@ def handle_dynamic_macro_call(node, macros, symbols):
 
 
 def resolve_macro(fullname, macros, symbols):
-    # split name into namespaces and real name
-    namespaces = fullname.split('.')
-    name = namespaces.pop(-1)
-
     def _resolve(namespaces, name, macros, symbols):
         # traverse namespaces to actual macros+symbols dicts
         for ns in namespaces:
@@ -769,6 +765,9 @@ def resolve_macro(fullname, macros, symbols):
     try:
         return _resolve([], fullname, macros, symbols)
     except KeyError:
+        # split name into namespaces and real name
+        namespaces = fullname.split('.')
+        name = namespaces.pop(-1)
         if namespaces:
             return _resolve(namespaces, name, macros, symbols)
         else:
@@ -951,7 +950,7 @@ def eval_all(node, macros, symbols):
             elif node.tagName == 'xacro:arg':
                 name, default = check_attrs(node, ['name', 'default'], [])
                 if name not in substitution_args_context['arg']:
-                    substitution_args_context['arg'][name] = eval_text(default, symbols)
+                    substitution_args_context['arg'][name] = unicode(eval_text(default, symbols))
 
                 remove_previous_comments(node)
                 replace_node(node, by=None)
